pub enum ValidDisputeStatementKind {
Explicit,
BackingSeconded(Hash),
BackingValid(Hash),
ApprovalChecking,
ApprovalCheckingMultipleCandidates(BoundedVec<CandidateHash, ConstU32<{ MAX_COALESCE_APPROVALS }>>),
}Expand description
Different kinds of statements of validity on a candidate.
Variants
Explicit
An explicit statement issued as part of a dispute.
BackingSeconded(Hash)
A seconded statement on a candidate from the backing phase.
BackingValid(Hash)
A valid statement on a candidate from the backing phase.
ApprovalChecking
An approval vote from the approval checking phase.
ApprovalCheckingMultipleCandidates(BoundedVec<CandidateHash, ConstU32<{ MAX_COALESCE_APPROVALS }>>)
An approval vote from the new version. We can’t create this version until all nodes have been updated to support it and max_approval_coalesce_count is set to more than 1.
The number of coalesced candidates is bounded at the type level to at most
MAX_COALESCE_APPROVALS. This is a hard ceiling enforced at decode time; the effective
per-session limit is max_approval_coalesce_count, enforced dynamically when the statement
is validated.
Implementations
Sourceimpl ValidDisputeStatementKind
impl ValidDisputeStatementKind
Sourcepub fn is_backing(&self) -> bool
pub fn is_backing(&self) -> bool
Whether the statement is from the backing phase.