referrerpolicy=no-referrer-when-downgrade

ApprovedPeerId

Type Alias ApprovedPeerId 

pub type ApprovedPeerId = BoundedVec<u8, ConstU32<64>>;
Approved PeerId type. PeerIds in polkadot should typically be 32 bytes long but for identity multihash can go up to 64. Cannot reuse the PeerId type definition from the networking code as it’s too generic and extensible.

Aliased Type

pub struct ApprovedPeerId(/* private fields */);